(*  GREATIS MOUSE HOOK                                    *)
(*  Copyright (C) 2005-2014 Greatis Software              *)
(*                                                        *)
(*  http://www.greatis.com/delphicb/mousehook/            *)

unit Main;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  MouseHook, StdCtrls, ShellAPI;

type
  TFormMain = class(TForm)
    MouseHook: TMouseHook;
    LabelMouseHook: TLabel;
    LabelMouseHookValue: TLabel;
    LabelOnMouseMove: TLabel;
    LabelMouseMoveValue: TLabel;
    LabelMouseDown: TLabel;
    LabelMouseDownValue: TLabel;
    LabelMouseUp: TLabel;
    LabelMouseUpValue: TLabel;
    LabelMouseWheel: TLabel;
    LabelMouseWheelValue: TLabel;
    LabelMouseHWheelValue: TLabel;
    LabelMouseHWheel: TLabel;
    ButtonMore: TButton;
    ButtonClose: TButton;
    ButtonStartStop: TButton;
    procedure FormCreate(Sender: TObject);
    procedure FormShow(Sender: TObject);
    procedure _MouseHookMouseHook(Sender: TObject; Message: Word;
      Point: TPoint; MouseData, Flags, Time: Integer; ExtraInfo: Pointer);
    procedure MouseHookMouseMove(Sender: TObject; Shift: TShiftState; X,
      Y: Integer);
    procedure MouseHookMouseDown(Sender: TObject; Button: TMouseButton;
      Shift: TShiftState; X, Y: Integer);
    procedure MouseHookMouseUp(Sender: TObject; Button: TMouseButton;
      Shift: TShiftState; X, Y: Integer);
    procedure MouseHookMouseWheel(Sender: TObject; Shift: TShiftState;
      WheelDelta, X, Y: Integer);
    procedure MouseHookMouseHWheel(Sender: TObject; Shift: TShiftState;
      WheelDelta, X, Y: Integer);
    procedure ButtonMoreClick(Sender: TObject);
    procedure ButtonCloseClick(Sender: TObject);
    procedure ButtonStartStopClick(Sender: TObject);
    procedure MouseHookMouseHook(Sender: TObject; Message: Word; Point: TPoint;
      MouseData, Flags, Time: Integer; ExtraInfo: Pointer);
  private
    { Private declarations }
    function ShiftStateToString(Shift: TShiftState): string;
    function ButtonToString(Button: TMouseButton): string;
  public
    { Public declarations }
  end;

var
  FormMain: TFormMain;

implementation

{$R *.DFM}


function TFormMain.ShiftStateToString(Shift: TShiftState): string;
begin
  Result:='';
  if ssShift in Shift then Result:=Result+'Shift ';
  if ssCtrl in Shift then Result:=Result+'Ctrl ';
  if ssAlt in Shift then Result:=Result+'Alt ';
  if ssLeft in Shift then Result:=Result+'Left ';
  if ssMiddle in Shift then Result:=Result+'Middle ';
  if ssRight in Shift then Result:=Result+'Right ';
end;

function TFormMain.ButtonToString(Button: TMouseButton): string;
begin
  case Button of
    mbLeft: Result:='Left';
    mbRight: Result:='Right';
  else Result:='Middle';
  end;
end;

procedure TFormMain.FormCreate(Sender: TObject);
var
  LF: TLogFont;
begin
  SystemParametersInfo(SPI_GETICONTITLELOGFONT,SizeOf(LF),@LF,0);
  with LF,Font do
  begin
    ScaleBy(Abs(lfHeight),Abs(Height));
    Handle:=CreateFontIndirect(LF);
  end;
end;

procedure TFormMain.FormShow(Sender: TObject);
begin
  MouseHook.Active:=True;
end;

procedure TFormMain._MouseHookMouseHook(Sender: TObject; Message: Word;
  Point: TPoint; MouseData, Flags, Time: Integer; ExtraInfo: Pointer);
begin
  LabelMouseHookValue.Caption:=
    IntToHex(Message,8)+' '+
    IntToStr(Point.X)+':'+IntToStr(Point.Y)+' '+
    IntToHex(MouseData,1)+' '+
    IntToHex(Flags,1)+' '+
    IntToStr(Time)+' '+
    IntToHex(Integer(ExtraInfo),1);
end;

procedure TFormMain.MouseHookMouseMove(Sender: TObject; Shift: TShiftState;
  X, Y: Integer);
begin
  LabelMouseMoveValue.Caption:=
    IntToStr(X)+':'+IntToStr(Y)+' '+
    ShiftStateToString(Shift);
end;

procedure TFormMain.MouseHookMouseDown(Sender: TObject;
  Button: TMouseButton; Shift: TShiftState; X, Y: Integer);
begin
  LabelMouseDownValue.Caption:=
    IntToStr(X)+':'+IntToStr(Y)+' '+
    ButtonToString(Button)+' '+
    ShiftStateToString(Shift);
end;


procedure TFormMain.MouseHookMouseUp(Sender: TObject; Button: TMouseButton;
  Shift: TShiftState; X, Y: Integer);
begin
  LabelMouseUpValue.Caption:=
    IntToStr(X)+':'+IntToStr(Y)+' '+
    ButtonToString(Button)+' '+
    ShiftStateToString(Shift);
end;


procedure TFormMain.MouseHookMouseWheel(Sender: TObject;
  Shift: TShiftState; WheelDelta, X, Y: Integer);
begin
  LabelMouseWheelValue.Caption:=
    IntToStr(X)+':'+IntToStr(Y)+' '+
    ShiftStateToString(Shift)+' '+
    IntToStr(WheelDelta);
end;


procedure TFormMain.MouseHookMouseHook(Sender: TObject; Message: Word;
  Point: TPoint; MouseData, Flags, Time: Integer; ExtraInfo: Pointer);
begin
  LabelMouseHookValue.Caption:=
    IntToHex(Message,8)+' '+
    IntToStr(Point.X)+':'+IntToStr(Point.Y)+' '+
    IntToHex(MouseData,1)+' '+
    IntToHex(Flags,1)+' '+
    IntToStr(Time)+' '+
    IntToHex(Integer(ExtraInfo),1);
end;

procedure TFormMain.MouseHookMouseHWheel(Sender: TObject;
  Shift: TShiftState; WheelDelta, X, Y: Integer);
begin
  LabelMouseHWheelValue.Caption:=
    IntToStr(X)+':'+IntToStr(Y)+' '+
    ShiftStateToString(Shift)+' '+
    IntToStr(WheelDelta);
end;

procedure TFormMain.ButtonMoreClick(Sender: TObject);
begin
  ShellExecute(Handle,'open','http://www.greatis.com/delphicb/mousehook/',nil,nil,SW_SHOWDEFAULT);
end;

procedure TFormMain.ButtonCloseClick(Sender: TObject);
begin
  Application.Terminate;
end;

procedure TFormMain.ButtonStartStopClick(Sender: TObject);
begin
  with MouseHook,ButtonStartStop do
  begin
    Active:=not Active;
    if Active then Caption:='Stop'
    else Caption:='Start';
  end;
end;

end.
